@@ -3,15 +3,18 @@
 #' @description Classify habitats
 #'
 #' @param raster RasterLayer with continuous environmental values.
-#' @param classes Integer with number of classes.
-#' @param style Character with method of classification. See Details section for
-#' more information.
+#' @param return_breaks Logical if breaks should be returned as well.
+#' @param ... Arguments passed on to \code{classIntervals}.
 #'
 #' @details
 #' Classifies a RasterLayer from the \code{raster} packages with continuous
-#' values into n discrete classes. Consequently, classes are non-overlapping (and left-closed).
-#' For more information about the classification method, see \code{\link{classIntervals}} from
-#' the \code{classInt} package and/or the provided References.
+#' values into n discrete classes. The \code{cut} function used to classify the raster,
+#' uses \code{include.lowest = TRUE}.
+#'
+#' For more information about the classification methods, see \code{classIntervals} from
+#' the \code{classInt} package and/or the provided References. The help page of \code{classIntervals}
+#' also includes further possible arguments to find  breaks (e.g., different styles, number
+#' of classes, fixed breaks, etc.).
 #'
 #' @seealso
 #' \code{\link{classIntervals}}
@@ -19,7 +22,10 @@
 #' @return RasterLayer
 #'
 #' @examples
-#' landscape_classified <- classify_habitats(landscape, classes = 5)
+#' landscape_classified <- classify_habitats(landscape, n = 5, style = "fisher")
+#'
+#' landscape_classified <- classify_habitats(landscape, style = "fixed",
+#' fixedBreaks = c(0, 0.25, 0.75, 1.0), return_breaks = TRUE)
 #'
 #' @aliases classify_habitats
 #' @rdname classify_habitats
@@ -39,19 +45,35 @@
 #' reduction. Annals of the Association of American Geographers 61, 217–244.
 #' <https://doi.org/10.1111/j.1467-8306.1971.tb00779.x>
 #'
+#' Jiang, B., 2013. Head/tail breaks: A new classification scheme for data with a
+#' heavy-tailed distribution. The Professional Geographer 65, 482-494.
+#' <https://doi.org/10.1080/00330124.2012.700499>
+#'
 #' Slocum, T.A., McMaster, R.B., Kessler, F.C., Howard, H.H., 2009. Thematic cartography
 #' and geovisualization, 3rd ed. ed, Prentice Hall Series in Geographic Information Science.
 #' Pearson Prentice Hall, Upper Saddle River, USA. ISBN 978-0-13-229834-6
 #'
+#' Wand, M. P., 1995. Data-based choice of histogram binwidth. The American
+#' Statistician 51, 59-64. <https://doi.org/10.1080/00031305.1997.10473591>
+#'
 #' @export
-classify_habitats <- function(raster, classes = 5, style = "fisher"){
+classify_habitats <- function(raster, return_breaks = FALSE, ...){
 
   raster_values <- raster::values(raster) # get all values
 
-  breaks <- classInt::classIntervals(var = raster_values,
-                                     n = classes, style = style) # get class intervals
+  breaks <- classInt::classIntervals(var = raster_values, ...) # use classInt to find breaks
 
   result <- raster::cut(raster, breaks = breaks$brks, include.lowest = TRUE) # classify raster
 
-  return(result)
+  # return RasterLayer and breaks
+  if (return_breaks) {
+
+    return(list(raster = result, breaks = breaks))
+
+  # return only RasterLayer
+  } else {
+
+    return(result)
+
+  }
 }
