@@ -7,6 +7,8 @@
 #' @param raster RasterLayer with original discrete habitat data or rd_ras object with
 #' randomized environmental data.
 #' @param significance_level Double with significance level.
+#' @param breaks Vector with breaks of habitat classes.
+#' @param digits Integer with digits used during rounding.
 #' @param verbose Logical if messages should be printed.
 #'
 #' @details
@@ -19,6 +21,10 @@
 #' In case the RasterLayer contains NA cells, this needs to be reflected in the observation
 #' window of the point pattern as well (i.e., no point locations possible in these areas).
 #'
+#' If \code{breaks = NULL} (default), only habitat labels (but not breaks) will be
+#' returned. If a vector with \code{breaks} is provided (same order as increasing habitat values),
+#' the breaks will be included as well.
+#'
 #' @seealso
 #' \code{\link{reconstruct_pattern}} \cr
 #' \code{\link{fit_point_process}}
@@ -26,7 +32,7 @@
 #' @return data.frame
 #'
 #' @examples
-#' landscape_classified <- classify_habitats(landscape, classes = 5)
+#' landscape_classified <- classify_habitats(landscape, n = 5, style = "fisher")
 #' species_a_random <- fit_point_process(species_a, n_random = 199)
 #' results_habitat_association(pattern = species_a_random, raster = landscape_classified)
 #'
@@ -44,8 +50,8 @@
 #' <https://doi.org/10.1006/jtbi.2000.2158>
 #'
 #' @export
-results_habitat_association <- function(pattern, raster,
-                                        significance_level = 0.05, verbose = TRUE) {
+results_habitat_association <- function(pattern, raster, significance_level = 0.05,
+                                        breaks = NULL, digits = NULL, verbose = TRUE) {
 
   if (!inherits(x = pattern, what = "rd_pat") && !inherits(x = raster, what = "rd_ras")) {
 
@@ -82,6 +88,14 @@ results_habitat_association <- function(pattern, raster,
 
     }
 
+    # check if pattern is ppp
+    if (!inherits(x = pattern, what = "ppp")) {
+
+      stop("Pleaster provide 'ppp' as pattern argument.", call. = FALSE)
+
+    }
+
+
     # check if extent is identical
     same_extent <- raster::extent(raster$observed) == raster::extent(pattern$window$xrange,
                                                                      pattern$window$yrange)
@@ -95,12 +109,12 @@ results_habitat_association <- function(pattern, raster,
 
     habitats <- sort(table(raster$observed@data@values, useNA = "no")) # get table of habitats
 
-    # print warning if more than 10 classes are present
+    # print warning if more than 25 classes are present
     if (verbose) {
 
-      if (length(habitats) > 10) {
+      if (length(habitats) > 25) {
 
-        warning("The raster has more than 10 classes. Please make sure discrete classes are provided.",
+        warning("The raster has more than 25 classes. You can ignore this warning if your raster data is discrete.",
                 call. = FALSE)
 
       }
@@ -141,6 +155,13 @@ results_habitat_association <- function(pattern, raster,
 
     }
 
+    # check of raster is RasterLayer
+    if (!inherits(x = raster, what = "RasterLayer")) {
+
+      stop("Pleaster provide 'RasterLayer' as raster argument.", call. = FALSE)
+
+    }
+
     # check if extent is identical
     same_extent <- raster::extent(raster) == raster::extent(pattern$observed$window$xrange,
                                                             pattern$observed$window$yrange)
@@ -161,12 +182,12 @@ results_habitat_association <- function(pattern, raster,
 
     habitats <- sort(table(raster@data@values, useNA = "no")) # get table of habitats
 
-    # print warning if more than 10 classes are present
+    # print warning if more than 25 classes are present
     if (verbose) {
 
-      if (length(habitats) > 10) {
+      if (length(habitats) > 25) {
 
-        warning("The raster has more than 10 classes. Please make sure discrete classes are provided.",
+        warning("The raster has more than 25 classes. You can ignore this warning if your raster data is discrete.",
                 call. = FALSE)
 
       }
@@ -195,20 +216,14 @@ results_habitat_association <- function(pattern, raster,
     })
   }
 
-  # count number of habitats
-  number_habitats <- length(unique(habitats_count$observed$habitat))
-
-  # combine to one df
-  names <- names(habitats_count)
-
   # repeat each name as often as number of habitats
-  names <- rep(names, each = number_habitats)
+  names_obj <- rep(x = names(habitats_count), each = length(habitats))
 
   # rowbind to one dataframe
   habitats_count <- do.call(rbind, unname(habitats_count))
 
   # add id
-  habitats_count$type <- names
+  habitats_count$type <- names_obj
 
   # only randomized data
   habitats_count_random <- habitats_count[habitats_count$type != "observed", ]
@@ -224,6 +239,24 @@ results_habitat_association <- function(pattern, raster,
   # convert to dataframe
   names(habitats_count_random_summarised) <- c("habitat", "lo", "hi")
 
+  # adding breaks to data.frame
+  if (is.null(breaks)) {
+
+    habitats_count_random_summarised$breaks <- rep(x = NA, times = length(habitats))
+
+  } else {
+
+    # check class
+    if (inherits(x = breaks, what = "classIntervals")) {
+
+      breaks <- classint_to_vector(x = breaks, digits = digits)
+
+    }
+
+    habitats_count_random_summarised$breaks <- breaks
+
+  }
+
   # get observed data
   habitats_count_obs <- habitats_count[habitats_count$type == "observed", 1:2]
 
@@ -237,5 +270,8 @@ results_habitat_association <- function(pattern, raster,
                                 no = ifelse(test = result$count > result$hi,
                                             yes = "positive", no = "n.s."))
 
+  # reorder columns
+  result <- result[, c("habitat", "breaks", "count", "lo", "hi", "significance")]
+
   return(result)
 }
