@@ -1,6 +1,6 @@
 library(dplyr)
 library(shar)
-library(spatstat)
+library(spatstat.core)
 library(testthat)
 
 test_check("shar")
